#!/bin/bash

#PURPOSE OF THIS SCRIPT: PREPARE INPUT FILES (INDIVIDUAL FILES RUN THROUGH TRIMMOMATIC) FOR DOWNSTREAM USE IN CONCOCT
. $config

echo -n "" > $cmds_log

# All stdout and stderr will go to individual per job *.o and *.e, so will not be piping to a log file.
#Prepare files for binning with CONCOCT

samFile=$out_dir$sid".vs."$indexKey".sam"
bamFile=$out_dir$sid".vs."$indexKey".bam"
sortedbamFile=$out_dir$sid".vs."$indexKey"-s"
alignedFile=$out_dir$sid".vs."$indexKey".aligned"
bowtiestatsFile=$out_dir$sid".vs."$indexKey".bowtie.stats"
markduplicatesinFile=$out_dir$sid".vs."$indexKey"-s.bam"
markduplicatesoutFile=$out_dir$sid".vs."$indexKey"-smd.bam"
markduplicatesmetricsFile=$out_dir$sid".vs."$indexKey"-smd.metrics"
sortedbamFile2=$out_dir$sid".vs."$indexKey"-smds"
coverageFile=$out_dir$sid".vs."$indexKey"-smds.coverage"

#Align trimmed, QCed individual sample file to assembled contigs file (from megahit), which has first been indext with bowtie2-build
  cmd="/opt/exp_soft/bowtie2-2.2.6/bowtie2 -q -N 1 -p 10 -x "$indexBase$indexKey" -U "$fastqFile" -S "$samFile" --al "$alignedFile" --rg-id "$sid" >> $bowtiestatsFile 2>&1"
  echo $cmd >> $cmds_log
  eval $cmd

#The -N flag specifies the number of mismatches allowed per seed (Can be set to 0 or 1, default 0) 
#The -x flag is to specify the basename for the indexed reference genome (in this case indexed contigs file with base name bowtie2_index - the default naming)
#The -q flag specifies that reads are fastq format (default)
#The -p flag specifies the number of threads to run in parallel (in this case 10)
#The -U flag is for a comma-separated list of files containing unpaired reads to be aligned
#The -S flag is the file to write the SAM alignements to
#The --al flag Write unpaired reads that align at least once to file at <path>
#the --rg-id flag Set the read group ID to <text>. This causes the SAM @RG header line to be printed, with <text> as the value associated with the ID: tag

#The following command takes the original contigs file and indexes it. Help file describes faidx as 'faidx – an index enabling random access to FASTA files'
  cmd="/opt/exp_soft/samtools-1.2/samtools faidx "$contigs_file
  echo $cmd >> $cmds_log  
  eval $cmd
#If @SQ lines are absent from our input file we need to first do samtools faidx ref.fa, which will automatically
#create an output file names ref.fa.fai. This command can be followed by samtools view -bt ref.fa.fai aln.sam > aln.bam

#The following command converts SAM to BAM
  cmd="/opt/exp_soft/samtools-1.2/samtools view -bt "$contigs_file".fai "$samFile" > "$bamFile
  echo $cmd >> $cmds_log  
  eval $cmd
#The -b flag says output in BAM format
#The -t flag provides additional reference data (required when SAM input does not require @SQ headers)

#The following command sorts the BAM file so that the alignments occur in 'genome order' - not sure what this means if you're aligning with a contigs file though?
  cmd="/opt/exp_soft/samtools-1.2/samtools sort "$bamFile" "$sortedbamFile
  echo $cmd >> $cmds_log  
  eval $cmd

#The following command indexes the sorted BAM file
  cmd="/opt/exp_soft/samtools-1.2/samtools index "$sortedbamFile".bam"
  echo $cmd >> $cmds_log  
  eval $cmd

#The following command locates and tags and removes duplicate reads in a BAM or SAM file where duplicate reads are defined as originating from a single fragment of DNA
  cmd="java -Xmx512m -Xmx10g -XX:ParallelGCThreads=10 -XX:MaxPermSize=1g -XX:+CMSClassUnloadingEnabled -jar "$mrkdup_path" INPUT="$markduplicatesinFile" OUTPUT="$markduplicatesoutFile" METRICS_FILE="$markduplicatesmetricsFile" AS=TRUE VALIDATION_STRINGENCY=LENIENT MAX_FILE_HANDLES_FOR_READ_ENDS_MAP=1000 REMOVE_DUPLICATES=TRUE"
  echo $cmd >> $cmds_log  
  eval $cmd

#After duplicates have been removed, sort the output file
  cmd="/opt/exp_soft/samtools-1.2/samtools sort "$markduplicatesoutFile" "$sortedbamFile2
  echo $cmd >> $cmds_log
  eval $cmd

#Index the sorted file
  cmd="/opt/exp_soft/samtools-1.2/samtools index "$sortedbamFile2".bam"
  echo $cmd >> $cmds_log
  eval $cmd

#will compute a histogram of coverage for the file provided 
  cmd="/opt/exp_soft/bedtools2/bin/genomeCoverageBed -ibam "$sortedbamFile2".bam > "$coverageFile
  echo $cmd >> $cmds_log
  eval $cmd

  cmd="rm "$samFile" "$bamFile
  echo $cmd >> $cmds_log  
  eval $cmd

  echo "Job Ended at `date`"
