#!/bin/bash

#set -x

#if the first column is empty it prints the message "Please provide a config"
if [ "$1" == "" ]
then
  echo "Please provide a config"
  echo
  exit
else
 config=`readlink -m $1`
  . $config
fi

if [ ! -d $out_dir ];
 then
   mkdir -p $out_dir
fi

log_dir=$log_dir"/trimmomatic_filter."`date +"%y%m%d%H%M%S"`

if [ ! -d $log_dir ];
 then
   mkdir -p $log_dir
fi

count=1

while read sid_fastq_pair;
do 
  sid=`echo $sid_fastq_pair | awk -F ' ' '{print $1}'` # It is actually not reading it as a TAB. Maybe the read operation replaces the TABs with spaces.
#KL: the above line gets the sample ID from the sid_fastq_pair file
 
  F_fastq=$in_dir/${sid}_pass_1.fastq #change as neccesary 
  R_fastq=$in_dir/${sid}_pass_2.fastq
  F_paired=$out_dir/${sid}.1.paired.fq.gz
  R_paired=$out_dir/${sid}.2.paired.fq.gz
  F_unpaired=$out_dir/${sid}.1.unpaired.fq.gz
  R_unpaired=$out_dir/${sid}.2.unpaired.fq.gz 

  cmds_log=$log_dir/trimmomatic_filter.$sid.$count.cmds

  qsub="qsub -N trimmomatic_filter.$sid.$count  -M $pbs_status_mail_to -m $pbs_status_mail_events -o $log_dir/trimmomatic_filter.$sid.$count.o -e $log_dir/trimmomatic_filter.$sid.$count.e -d $out_dir -q $pbs_queue -S /bin/bash -l nodes=1:$pbs_series:ppn=$trimmomatic_threads -l walltime=$trimmomatic_filter_walltime -v config=$config,F_fastq=$F_fastq,R_fastq=$R_fastq,F_paired=$F_paired,R_paired=$R_paired,F_unpaired=$F_unpaired,R_unpaired=$R_unpaired,trimmomatic_path=$trimmomatic_path,MINLEN=$MINLEN,cmds_log=$cmds_log $scripts_dir/trimmomatic_filter.single.sh"

  echo $qsub > $log_dir/trimmomatic_filter.$sid.$count.qsub
  cat $scripts_dir/trimmomatic_filter.single.sh > $log_dir/trimmomatic_filter.$sid.$count.sh

  if [ $trimmomatic_filter_DEBUG -eq 1 ]
   then
     echo $qsub
   else
     jobid=`$qsub`
     echo $jobid
     echo $jobid > $log_dir/trimmomatic_filter.$sid.$count.jobid
   fi

   (( count+=1 ))


done < $sid_fastq_pair_list

